[23203] in Source-Commits

home help back first fref pref prev next nref lref last post

/svn/athena r22864 - in trunk/athena/bin/discuss: client debian edsc libds mclient server

daemon@ATHENA.MIT.EDU (andersk@MIT.EDU)
Sun Apr 6 20:27:12 2008

Date: Sun, 6 Apr 2008 20:26:42 -0400 (EDT)
From: andersk@MIT.EDU
Message-Id: <200804070026.UAA03581@drugstore.mit.edu>
To: source-commits@MIT.EDU
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit

Author: andersk
Date: 2008-04-06 20:26:41 -0400 (Sun, 06 Apr 2008)
New Revision: 22864

Modified:
   trunk/athena/bin/discuss/client/discuss.c
   trunk/athena/bin/discuss/debian/changelog
   trunk/athena/bin/discuss/edsc/edsc.c
   trunk/athena/bin/discuss/libds/auth_krb.c
   trunk/athena/bin/discuss/libds/rpcall.c
   trunk/athena/bin/discuss/libds/stubs.c
   trunk/athena/bin/discuss/mclient/crmtgs.c
   trunk/athena/bin/discuss/mclient/dsmail.c
   trunk/athena/bin/discuss/mclient/dspipe.c
   trunk/athena/bin/discuss/mclient/mkds.c
   trunk/athena/bin/discuss/mclient/pmtg.c
   trunk/athena/bin/discuss/server/expunge.c
   trunk/athena/bin/discuss/server/expunge2.c
   trunk/athena/bin/discuss/server/recover.c
   trunk/athena/bin/discuss/server/rpproc.c
Log:
Fix obsolete names for Kerberos library functions, which no longer
worked on Mac OS X.  Patch from broder.


Modified: trunk/athena/bin/discuss/client/discuss.c
===================================================================
--- trunk/athena/bin/discuss/client/discuss.c	2008-04-07 00:24:57 UTC (rev 22863)
+++ trunk/athena/bin/discuss/client/discuss.c	2008-04-07 00:26:41 UTC (rev 22864)
@@ -154,8 +154,8 @@
 		ss_perror(sci_idx, code, INFO_DIR);
 	}
 
-	init_disc_err_tbl();
-	init_dsc_err_tbl();
+	initialize_disc_error_table();
+	initialize_dsc_error_table();
 
 	temp_file = malloc(64);
 	pgm = malloc(64);

Modified: trunk/athena/bin/discuss/debian/changelog
===================================================================
--- trunk/athena/bin/discuss/debian/changelog	2008-04-07 00:24:57 UTC (rev 22863)
+++ trunk/athena/bin/discuss/debian/changelog	2008-04-07 00:26:41 UTC (rev 22864)
@@ -1,3 +1,10 @@
+debathena-discuss (10.0.1-0debathena1) unstable; urgency=low
+
+  * Fix obsolete names for Kerberos library functions, which no longer
+    worked on Mac OS X.  Patch from broder.
+
+ -- Anders Kaseorg <andersk@mit.edu>  Sun, 06 Apr 2008 19:25:13 -0400
+
 debathena-discuss (10.0.0-0debathena2) unstable; urgency=low
 
   * Actually use SERVERDIR, BINDIR, and INFODIR in config.h.sed.  (The

Modified: trunk/athena/bin/discuss/edsc/edsc.c
===================================================================
--- trunk/athena/bin/discuss/edsc/edsc.c	2008-04-07 00:24:57 UTC (rev 22863)
+++ trunk/athena/bin/discuss/edsc/edsc.c	2008-04-07 00:26:41 UTC (rev 22864)
@@ -122,7 +122,7 @@
      char *cp,*op,delim,*args;
      struct rlimit limit;
 
-     init_dsc_err_tbl();
+     initialize_dsc_error_table();
 
      temp_file = malloc(64);
      pgm = malloc(64);

Modified: trunk/athena/bin/discuss/libds/auth_krb.c
===================================================================
--- trunk/athena/bin/discuss/libds/auth_krb.c	2008-04-07 00:24:57 UTC (rev 22863)
+++ trunk/athena/bin/discuss/libds/auth_krb.c	2008-04-07 00:26:41 UTC (rev 22864)
@@ -74,7 +74,7 @@
 	 exit(1);
      }
 
-     init_krb_err_tbl();
+     initialize_krb_error_table();
 
      realmp = strchr (service_id, '@');
      if (realmp == NULL || realmp - service_id >= sizeof (serv)) {
@@ -131,7 +131,7 @@
 
      static KTEXT_ST ticket;
 
-     init_krb_err_tbl();
+     initialize_krb_error_table();
 
      realmp = strchr (service_id, '@');
      if (realmp == NULL || realmp - service_id >= sizeof (serv)) {
@@ -159,7 +159,7 @@
      } else {
 	 *authl = 0;
 	 *authp = NULL;
-	 *result = rem + krb_err_base;
+	 *result = rem + ERROR_TABLE_BASE_krb;
      }
 }
 

Modified: trunk/athena/bin/discuss/libds/rpcall.c
===================================================================
--- trunk/athena/bin/discuss/libds/stubs.c	2008-04-07 00:24:57 UTC (rev 22863)
+++ trunk/athena/bin/discuss/libds/stubs.c	2008-04-07 00:26:41 UTC (rev 22864)
@@ -51,7 +51,7 @@
      startsend(ADD_TRN);
      if (rpc_err) { *result = rpc_err; return; }
      sendstr(mtg_name);
-     sendfile(source_file);
+     rpc_sendfile(source_file);
      sendstr(subject);
      sendint(reply_trn);
      sendit(discuss);
@@ -85,7 +85,7 @@
      startsend(ADD_TRN2);
      if (rpc_err) { *result = rpc_err; return; }
      sendstr(mtg_name);
-     sendfile(source_file);
+     rpc_sendfile(source_file);
      sendstr(subject);
      sendstr(signature);
      sendint(reply_trn);
@@ -342,7 +342,7 @@
      if (rpc_err) { *result = rpc_err; return; }
      sendstr(mtg_name);
      sendint(trn);
-     sendfile(dest_file);
+     rpc_sendfile(dest_file);
      sendit(discuss);
      if (rpc_err) { *result = rpc_err; return; }
      recvdata(dest_file);

Modified: trunk/athena/bin/discuss/mclient/crmtgs.c
===================================================================
--- trunk/athena/bin/discuss/mclient/crmtgs.c	2008-04-07 00:24:57 UTC (rev 22863)
+++ trunk/athena/bin/discuss/mclient/crmtgs.c	2008-04-07 00:26:41 UTC (rev 22864)
@@ -37,7 +37,7 @@
 	char **aliasv;
 	int naliases;
 	
-	init_dsc_err_tbl();
+	initialize_dsc_error_table();
 
 	dsc_expand_mtg_set(NULL, "*", &set, &n_matches, &code);
 

Modified: trunk/athena/bin/discuss/mclient/dsmail.c
===================================================================
--- trunk/athena/bin/discuss/mclient/dsmail.c	2008-04-07 00:24:57 UTC (rev 22863)
+++ trunk/athena/bin/discuss/mclient/dsmail.c	2008-04-07 00:26:41 UTC (rev 22864)
@@ -89,7 +89,7 @@
      int i,ok_prev=0,iscont = 0, have_signature = 0, len, d;
      char filename[60], signature[35], field_name[100];
      
-     init_dsc_err_tbl();
+     initialize_dsc_error_table();
 
      PRS(argc,argv);				/* Parse args */
 

Modified: trunk/athena/bin/discuss/mclient/dspipe.c
===================================================================
--- trunk/athena/bin/discuss/mclient/dspipe.c	2008-04-07 00:24:57 UTC (rev 22863)
+++ trunk/athena/bin/discuss/mclient/dspipe.c	2008-04-07 00:26:41 UTC (rev 22864)
@@ -44,7 +44,7 @@
 	tfile tf;
 	int i,nread,d,exit_code;
 
-	init_dsc_err_tbl();
+	initialize_dsc_error_table();
 	for (i = 1; i < argc; i++) {
 		if (*argv[i] == '-')
 			switch (argv[i][1]) {

Modified: trunk/athena/bin/discuss/mclient/mkds.c
===================================================================
--- trunk/athena/bin/discuss/mclient/mkds.c	2008-04-07 00:24:57 UTC (rev 22863)
+++ trunk/athena/bin/discuss/mclient/mkds.c	2008-04-07 00:26:41 UTC (rev 22864)
@@ -63,7 +63,7 @@
 	tfile tf;
 	char hostname[256];
 
-	init_dsc_err_tbl();
+	initialize_dsc_error_table();
 
 	nbsrc.user_id = malloc(132);
 

Modified: trunk/athena/bin/discuss/mclient/pmtg.c
===================================================================
--- trunk/athena/bin/discuss/mclient/pmtg.c	2008-04-07 00:24:57 UTC (rev 22863)
+++ trunk/athena/bin/discuss/mclient/pmtg.c	2008-04-07 00:26:41 UTC (rev 22864)
@@ -35,7 +35,7 @@
 	tfile tfstdout;
 	char machine [50],mtg_name[100];
 
-	init_dsc_err_tbl();
+	initialize_dsc_error_table();
 	argc--; argv++;
 	if (argc != 1)
 		goto lusage;

Modified: trunk/athena/bin/discuss/server/expunge.c
===================================================================
--- trunk/athena/bin/discuss/server/expunge.c	2008-04-07 00:24:57 UTC (rev 22863)
+++ trunk/athena/bin/discuss/server/expunge.c	2008-04-07 00:26:41 UTC (rev 22864)
@@ -72,7 +72,7 @@
      static struct flock lock;
 
 
-     init_dsc_err_tbl();
+     initialize_dsc_error_table();
 
      for (i = 1; i < argc; i++) {
 	  if (*argv[i] == '-') switch (argv[i][1]) {

Modified: trunk/athena/bin/discuss/server/expunge2.c
===================================================================
--- trunk/athena/bin/discuss/server/expunge2.c	2008-04-07 00:24:57 UTC (rev 22863)
+++ trunk/athena/bin/discuss/server/expunge2.c	2008-04-07 00:26:41 UTC (rev 22864)
@@ -55,7 +55,7 @@
      char control_name[256];
      int control_fd;
      
-     init_dsc_err_tbl();
+     initialize_dsc_error_table();
 
      for (i = 1; i < argc; i++) {
 	  if (*argv[i] == '-') switch (argv[i][1]) {

Modified: trunk/athena/bin/discuss/server/recover.c
===================================================================
--- trunk/athena/bin/discuss/server/recover.c	2008-04-07 00:24:57 UTC (rev 22863)
+++ trunk/athena/bin/discuss/server/recover.c	2008-04-07 00:26:41 UTC (rev 22864)
@@ -101,7 +101,7 @@
      has_privs = TRUE;
      use_zephyr = 0;
 
-     init_dsc_err_tbl();
+     initialize_dsc_error_table();
 
      for (i = 1; i < argc; i++) {
 	  if (*argv[i] == '-') switch (argv[i][1]) {

Modified: trunk/athena/bin/discuss/server/rpproc.c
===================================================================
--- trunk/athena/bin/discuss/server/rpproc.c	2008-04-07 00:24:57 UTC (rev 22863)
+++ trunk/athena/bin/discuss/server/rpproc.c	2008-04-07 00:26:41 UTC (rev 22864)
@@ -116,7 +116,7 @@
     USPCardinal bt;
 #endif	  
 
-    init_rpc_err_tbl();
+    initialize_rpc_error_table();
 
 #ifdef INETD
     d = open ("/dev/null", 2);
@@ -314,7 +314,7 @@
         result = krb_rd_req (&ticket, service, instance, haddr, &kdata,
 	                     filename);
 	if (result) {
-	    result += krb_err_base;
+	    result += ERROR_TABLE_BASE_krb;
 	    goto punt_kerberos;
 	}
 #ifdef KERBEROS5
@@ -483,7 +483,7 @@
     int i;
 {
     if (USP_put_long_integer(us, i) != SUCCESS) {
-	rpc_err = errno + rpc_err_base;
+	rpc_err = errno + ERROR_TABLE_BASE_rpc;
     }
 }
 
@@ -498,7 +498,7 @@
     if (str == NULL)
       str = "";
     if (USP_put_string(us, str) != SUCCESS) {
-	rpc_err = rpc_err_base + errno;
+	rpc_err = ERROR_TABLE_BASE_rpc + errno;
 	return;
     }
 }
@@ -512,7 +512,7 @@
     bool b;
 {
     if (USP_put_boolean(us, (USPBoolean)b) != SUCCESS) {
-	rpc_err = rpc_err_base + errno;
+	rpc_err = ERROR_TABLE_BASE_rpc + errno;
 	return;
     }
 }
@@ -525,7 +525,7 @@
 sendreply()
 {
     if (USP_end_block(us) != SUCCESS) {
-	rpc_err = rpc_err_base + errno;
+	rpc_err = ERROR_TABLE_BASE_rpc + errno;
 	return;
     }
     return;
@@ -540,7 +540,7 @@
 {
     USP_begin_block(us,UNKNOWN_CALL);
     if (USP_end_block(us) != SUCCESS) {
-	rpc_err = rpc_err_base + errno;
+	rpc_err = ERROR_TABLE_BASE_rpc + errno;
 	return;
     }
     return;


home help back first fref pref prev next nref lref last post
--- trunk/athena/bin/discuss/libds/rpcall.c	2008-04-07 00:24:57 UTC (rev 22863)
+++ trunk/athena/bin/discuss/libds/rpcall.c	2008-04-07 00:26:41 UTC (rev 22864)
@@ -146,10 +146,10 @@
 
 /*
  *
  * sendfile(tf)  -- Send a file in an RPC call.
  *
  */
-void sendfile(tf)
+void rpc_sendfile(tf)
     tfile tf;
 {
     int tfs;
@@ -181,8 +181,8 @@
  */
 void init_rpc ()
 {
-    init_rpc_err_tbl();
-    init_usp_err_tbl();
+    initialize_rpc_error_table();
+    initialize_usp_error_table();
 }
 
 /*
@@ -146,10 +146,10 @@
 /*
  *
- * sendfile(tf)  -- Send a file in an RPC call.
+ * rpc_sendfile(tf)  -- Send a file in an RPC call.
  *
  */

Modified: trunk/athena/bin/discuss/libds/stubs.c
===================================================================